==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/nl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Federated sharing",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Wil je de externe share {name} van {owner}@{remote} toevoegen?",
    "Remote share" : "Externe share",
    "Remote share password" : "Wachtwoord externe share",
    "Cancel" : "Annuleren",
    "Add remote share" : "Toevoegen externe share",
    "Copy" : "Kopiëren",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund!",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Invalid Federated Cloud ID" : "Ongeldige Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server met server delen is op deze server niet geactiveerd",
    "Couldn't establish a federated share." : "Kon geen gefedereerde share tot stand brengen",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kon geen gefedereerde share tot stand brengen, misschien was het wachtwoord onjuist.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "De gefedereerde share aanvraag is geslaagd, je ontvangt een uitnodiging. Controleer je meldingen.",
    "The mountpoint name contains invalid characters." : "De naam van het mountpoint bevat ongeldige karakters.",
    "Not allowed to create a federated share with the owner." : "Het is niet toegestaan om met de eigenaar een gefedereerde share te maken.",
    "Invalid or untrusted SSL certificate" : "Ongeldig of onvertrouwd SSL-certificaat",
    "Could not authenticate to remote share, password might be wrong" : "Kon niet authenticeren bij externe share, misschien verkeerd wachtwoord",
    "Storage not valid" : "Opslag ongeldig",
    "Federated Share successfully added" : "Gefedereerde share succesvol toegevoegd",
    "Couldn't add remote share" : "Kon geen externe share toevoegen",
    "Sharing %s failed, because this item is already shared with %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met %s",
    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "File is already shared with %s" : "Bestand is al gedeeld met %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server niet bereikbaar of u gebruikt een zelf getekend certificaat.",
    "Could not find share" : "Kon share niet vinden",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Je ontving \"%3$s\" als een extern deel verzoek van %1$s (namens %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Je ontving {share} als een extern deel verzoek van {user} (namens {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Je ontving \"%3$s\" als een extern deel verzoek van %1$s",
    "You received {share} as a remote share from {user}" : "Je ontving {share} als een extren deel verzoek van {user}",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Deel met mij via mijn #Nextcloud federated Cloud ID, zie %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Deel met mij via mijn #Nextcloud federated Cloud ID",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentatie",
    "Allow users on this server to send shares to other servers" : "Toestaan dat gebruikers op deze server shares sturen naar andere servers",
    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
    "Search global and public address book for users" : "Doorzoeken globale en openbare adresboeken naar gebruikers",
    "Federated Cloud" : "Gefedereerde Cloud",
    "Your Federated Cloud ID:" : "Je Federated Cloud ID:",
    "Share it:" : "Deel het:",
    "Add to your website" : "Toevoegen aan je website",
    "Share with me via Nextcloud" : "Deel met mij via Nextcloud",
    "HTML Code:" : "HTML Code:",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server niet bereikbaar.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Je ontving \"/%3$s\" als een externe share van %1$s (namens %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Je ontving \"/%3$s\" als een externe share van %1$s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/nl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Gefedereerd delens",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Wil je de externe share {name} van {owner}@{remote} toevoegen?",
    "Remote share" : "Externe share",
    "Remote share password" : "Wachtwoord externe share",
    "Cancel" : "Annuleren",
    "Add remote share" : "Toevoegen externe share",
    "Copy" : "Kopiëren",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund!",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Invalid Federated Cloud ID" : "Ongeldige gefedereerde Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server met server delen is op deze server niet ingeschakeld",
    "Couldn't establish a federated share." : "Kon geen gefedereerde share tot stand brengen",
    "Couldn't establish a federated share, maybe the password was wrong." : "Kon geen gefedereerde share tot stand brengen, misschien was het wachtwoord onjuist.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "De gefedereerde share aanvraag is verzonden, je ontvangt een uitnodiging. Controleer je meldingen.",
    "The mountpoint name contains invalid characters." : "De naam van het mountpoint bevat ongeldige karakters.",
    "Not allowed to create a federated share with the owner." : "Het is niet toegestaan om met de eigenaar een gefedereerde share te maken.",
    "Invalid or untrusted SSL certificate" : "Ongeldig of onvertrouwd SSL-certificaat",
    "Could not authenticate to remote share, password might be wrong" : "Kon niet authenticeren bij externe share, misschien verkeerd wachtwoord",
    "Storage not valid" : "Opslag ongeldig",
    "Federated share added" : "Gefedereerd share is toegevoegd",
    "Couldn't add remote share" : "Kon geen externe share toevoegen",
    "Sharing %s failed, because this item is already shared with %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met %s",
    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
    "File is already shared with %s" : "Bestand is al gedeeld met %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delen van %s mislukt, kon %s niet vinden, misschien is de server niet bereikbaar of u gebruikt een zelf getekend certificaat.",
    "Could not find share" : "Kon share niet vinden",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Je ontving \"%3$s\" als een extern deel verzoek van %1$s (namens %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Je ontving {share} als een extern deel verzoek van {user} (namens {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Je ontving \"%3$s\" als een extern deel verzoek van %1$s",
    "You received {share} as a remote share from {user}" : "Je ontving {share} als een extren share verzoek van {user}",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Deel met mij via mijn #Nextcloud gefedereerde Cloud ID, zie %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Deel met mij via mijn #Nextcloud gefedereerde Cloud ID",
    "Sharing" : "Delen",
    "Federated file sharing" : "Gefedereerd bestand delen",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Open documentatie",
    "Adjust how people can share between servers." : "Aanpassen hoe mensen tussen servers kunnen delen.",
    "Allow users on this server to send shares to other servers" : "Toestaan dat gebruikers op deze server shares sturen naar andere servers",
    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
    "Search global and public address book for users" : "Doorzoeken van openbare adresboeken voor gebruikers",
    "Allow users to publish their data to a global and public address book" : "Publiek maken van data met een openbaar adresboek toestaan",
    "Federated Cloud" : "Gefedereerde Cloud",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Je kunt met iedereen delen die Nextcloud, ownCloud of Pydio gebruikt! Gebruik simpelweg hun gefedereerde Cloud ID in de deel-dialoog. Het ziet eruit als iemand@cloud.voorbeeld.com",
    "Your Federated Cloud ID:" : "Je gefedereerde Cloud ID:",
    "Share it so your friends can share files with you:" : "Deel het, zodat anderen bestanden met jou kunnen delen:",
    "Add to your website" : "Toevoegen aan je website",
    "Share with me via Nextcloud" : "Deel met mij via Nextcloud",
    "HTML Code:" : "HTML Code:",
    "Search global and public address book for users and let local users publish their data" : "Openbare adresboeken voor gebruikers doorzoeken en laat lokale gebruikers de data plubliceren",
    "Share it:" : "Deel het:"
},
"nplurals=2; plural=(n != 1);");
